@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(to_ascii to_latin1);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my %ascii = (qw(
          A
@@ -84,7 +84,10 @@ my %ascii = (qw(
 		 ue
 		 P
 		 .
-		 ^1),
+		 ^1
+         >>
+         <<
+        ),
 	     ("" => "'",
 	      "" => ",",
           "" => "(R)",
@@ -476,6 +479,10 @@ sub to_latin1($) {
     s/\(R\)//g;
     s/\(C\)//g;
 
+    # special characters
+    s/<<(\D*?)>>/$1/g;    # if there are numbers between,
+    s/>>(\D*?)<</$1/g;    # it could be also a mathematical/physical equation
+
     # foreign words
     s/cademie/cadmie/g;
     s/rancais/ranais/g;
@@ -701,7 +708,7 @@ sub to_latin1($) {
     s/Angstrm/ngstrm/g;
     s/Egalite/galit/g;
     s/(?<=[Ll]and)bue/busse/g;
-    s/a(?=\W+(?:condition|deux mains|fonds perdu|gogo|jour|la))//g;
+    s/\ba(?=\W+(?:condition|deux mains|fonds perdu|gogo|jour|la))//g;
     s/a discretion/ discrtion/g;
     s/(?<=[Bb]ai)(?=e)/ss/g;
     s/(?<=[Hh]au)(?=e)/ss/g;
@@ -810,6 +817,7 @@ sub to_latin1($) {
     s/tnte/tuente/g;
     s/tlle/tuelle/g;
     s/([\w   ]+t)ll/$1 eq lc($1) ? "$1uell" : "$1ll"/gex; #eventuell != Hkeltll    
+    s/Eventll/Eventuell/g;
     s/Lang/Langue/g;
     s/Manl/Manuel/g;
     s/Migl/Miguel/g;
